################################################################
:mod:`.accessibility <highcharts_core.options.accessibility>`
################################################################

.. contents:: Module Contents
  :local:
  :depth: 3
  :backlinks: entry

.. toctree::
  :titlesonly:

  announce_new_data
  keyboard_navigation/index
  point
  screen_reader_section
  series

--------------

.. module:: highcharts_core.options.accessibility

****************************************************************************************
class: :class:`Accessibility <highcharts_core.options.accessibility.Accessibility`>
****************************************************************************************

.. autoclass:: Accessibility
  :members:
  :inherited-members:

  .. collapse:: Class Inheritance

    .. inheritance-diagram:: Accessibility
      :top-classes: highcharts_core.metaclasses.HighchartsMeta
      :parts: -1

  |

-----------------------

***************************************************************************************************************************
class: :class:`CustomAccessibilityComponents <highcharts_core.options.accessibility.CustomAccessibilityComponents`>
***************************************************************************************************************************

.. autoclass:: CustomAccessibilityComponents
  :members:
  :inherited-members:

  .. collapse:: Class Inheritance

    .. inheritance-diagram:: CustomAccessibilityComponents
      :top-classes: highcharts_core.metaclasses.HighchartsMeta
      :parts: -1

  |

--------------------

***************************
Sub-components
***************************

.. list-table::
  :widths: 60 40
  :header-rows: 1

  * - Module
    - Classes / Functions
  * - :mod:`.options.accessibility <highcharts_core.options.accessibility>`
    - :class:`Accessibility <highcharts_core.options.accessibility.Accessibility>`
      :class:`CustomAccessibilityComponents <highcharts_core.options.accessibility.CustomAccessibilityComponents>`
  * - :mod:`.options.accessibility.announce_new_data <highcharts_core.options.accessibility.announce_new_data>`
    - :class:`AnnounceNewData <highcharts_core.options.accessibility.announce_new_data.AnnounceNewData>`
  * - :mod:`.options.accessibility.keyboard_navigation <highcharts_core.options.accessibility.keyboard_navigation>`
    - :class:`KeyboardNavigation <highcharts_core.options.accessibility.keyboard_navigation.KeyboardNavigation>`
  * - :mod:`.options.accessibility.keyboard_navigation.focus_border <highcharts_core.options.accessibility.keyboard_navigation.focus_border>`
    - :class:`FocusBorder <highcharts_core.options.accessibility.keyboard_navigation.focus_border.FocusBorder>`
      :class:`FocusBorderStyle <highcharts_core.options.accessibility.keyboard_navigation.focus_border.FocusBorderStyle>`
  * - :mod:`.options.accessibility.keyboard_navigation.series_navigation <highcharts_core.options.accessibility.keyboard_navigation.series_navigation>`
    - :class:`SeriesNavigation <highcharts_core.options.accessibility.keyboard_navigation.series_navigation.SeriesNavigation>`
  * - :mod:`options.accessibility.point <highcharts_core.options.accessibility.point>`
    - :class:`AccessibilityPoint <highcharts_core.options.accessibility.point.AccessibilityPoint>`
  * - :mod:`options.accessibility.screen_reader_section <highcharts_core.options.accessibility.screen_reader_section>`
    - :class:`ScreenReaderSection <highcharts_core.options.accessibility.screen_reader_section.ScreenReaderSection>`
  * - :mod:`options.accessibility.series <highcharts_core.options.accessibility.series>`
    - :class:`SeriesAccessibility <highcharts_core.options.accessibility.series.SeriesAccessibility>`
